-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- Written by Kimberly L. Tripp, SQLskills.com
-- All Rights Reserved.
-- 
-- For more scripts, sample code and additional training resources,
-- go to http://www.SQLskills.com
--	Immerse yourself in SQL Server
--
-- Disclaimer - Thoroughly test this script, execute at your own risk.
-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

/* ***************************************************************** **
** This script was originally used in a series of articles in SQL Server 
** Magazine to describe joins. 		
** NOTE: The state of 127 ONLY kills the client connection when this
** script is RUN via OSQL. If run in Query Analyzer you could end up 
** with all of the objects being created in your master database. You
** are best to use this script from a command prompt and execute:
	osql -E -i"Join Examples - DB Setup.sql" -o"Join DB Setup OUTPUT.txt"
** Make sure you are in the proper directory.
** ***************************************************************** */

USE master
GO
IF DATABASEPROPERTYEX('TSQLTutorJoins', 'COLLATION') IS NOT NULL
BEGIN
	RAISERROR ('A TSQLTutorJoins database already exists. This script will NOT execute unless you review the code to include a DROP DATABASE. Please use your best judgement as to whether this is a good idea. Thanks, kt', 16, 127)
	-- The state of 127 causes the connection to be killed. 
	-- If you're using osql, this is a great feature because the 
	-- rest of the script will NOT continue to execute.

	-- If DROP DATABASE is desired, comment out the Raiserror and 
	-- uncomment the following DROP DATABASE line.

	-- DROP DATABASE TSQLTutorJoins
END
GO

CREATE DATABASE TSQLTutorJoins
GO

IF DATABASEPROPERTYEX('TSQLTutorJoins', 'COLLATION') IS NULL
BEGIN
	RAISERROR ('The TSQLTutorJoins Database WAS NOT CREATED. This script will NOT continue to unless you review the errors and create the TSQLTutorJoins database. Please use your best judgement as to whether this is a good idea. Thanks, kt', 16, 127)
	-- The state of 127 causes the connection to be killed. 
	-- If you're using osql, this feature is great because the 
	-- rest of the script won't continue to execute. However, if 
	-- you open and run this code in Query Analyzer, QA will  
	-- reconnect after a connection is lost. If TSQLTutorJoins 
	-- wasn't created, all the following objects will end 
	-- up in the master database.
END
GO

USE TSQLTutorJoins
GO

CREATE TABLE dbo.Customer 
(
	CustomerID		int    		NOT NULL
									IDENTITY(1,1)
                		 					CONSTRAINT CustomerPK
										PRIMARY KEY CLUSTERED,
	FirstName		varchar(15) 	NOT NULL,
	MiddleInitial	char(1)			NULL,
	LastName		varchar(20) 	NOT NULL  
)
GO

CREATE TABLE dbo.Category
(
	CategoryID		tinyint			NOT NULL
									IDENTITY(1,1)
                		 					CONSTRAINT CategoryPK
										PRIMARY KEY CLUSTERED,
	CategoryName	varchar(20)		NOT NULL,
	Description	varchar(1000)	NULL
)


CREATE TABLE dbo.Product
(
	ProductID 		smallint		NOT NULL
									IDENTITY(1,1)
                		 					CONSTRAINT ProductPK
										PRIMARY KEY CLUSTERED,
	ProductName	varchar(25) 	NOT NULL,
	CategoryID		tinyint			NOT NULL
									CONSTRAINT ProductCategoryFK
										FOREIGN KEY (CategoryID)
											REFERENCES dbo.Category(CategoryID)
)
GO

CREATE TABLE dbo.[Order]
(
	OrderID		int				NOT NULL	
									IDENTITY(1,1)
                		 					CONSTRAINT OrderPK
										PRIMARY KEY CLUSTERED,
	OrderDate		datetime		NOT NULL
									CONSTRAINT OrderOrderDateDflt
										DEFAULT CURRENT_TIMESTAMP,
--										DEFAULT getdate(),
	CustomerID 	int  			NULL
									CONSTRAINT OrderCustomerFK
										FOREIGN KEY (CustomerID)
											REFERENCES dbo.Customer(CustomerID),
	ProductID		smallint 		NOT NULL 
									CONSTRAINT OrderProductFK
										FOREIGN KEY (ProductID)
											REFERENCES dbo.Product(ProductID),
	Quantity		smallint 		NOT NULL 
)
GO

--Populate the Customer Table
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Arthur', 'A', 'Curry') 
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Bruce', 'B', 'Wayne') 
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Selina', 'C', 'Kyle') 
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Oswald', 'P', 'Cobblepot') 
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Eddie', 'R', 'Nashton') 
INSERT INTO dbo.Customer (FirstName, MiddleInitial, LastName)
	VALUES ('Diana', 'W', 'Prince') 
GO

SELECT * FROM dbo.Customer
GO

INSERT INTO dbo.Category (CategoryName)
	VALUES ('Jewelry')
INSERT INTO dbo.Category (CategoryName)
	VALUES ('Hardware')
INSERT INTO dbo.Category (CategoryName)
	VALUES ('Water-related')
GO

SELECT * FROM dbo.Category
GO

INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Umbrella', 3)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Rebreather', 3)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Tape', 2)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Jigsaw', 2)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Bracelet', 1)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Utility Belt', 2)
INSERT INTO dbo.Product (ProductName, CategoryID)
	VALUES ('Ring', 1)
GO

SELECT * FROM dbo.Product
GO

INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('08/07/2003', 6, 6, 2)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('09/14/2003', NULL, 2, 6) 
	-- Over-the-counter purchase with a NULL CustomerID 
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('01/16/2004', 6, 5, 100)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('03/08/2004', 5, 4, 3)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('03/09/2004', 2, 2, 2)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('04/01/2004', 1, 6, 12)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('05/12/2004', 2, 6, 1)
INSERT INTO dbo.[Order] (OrderDate, CustomerID, ProductID, Quantity)
	VALUES ('06/22/2004', NULL, 2, 1) 
	-- Over-the-counter purchase
GO

SELECT * FROM dbo.[Order]
GO